@@ -11,7 +11,7 @@ const handle = app.getRequestHandler();
 app.prepare().then(() => {
   const server = express();
 
-  server.all('/api', proxy(backendUrl));
+  server.all('/api*', proxy(backendUrl));
 
   server.all('*', (req, res) => {
     return handle(req, res);
@@ -19,6 +19,7 @@ app.prepare().then(() => {
 
   server.listen(port, err => {
     if (err) throw err;
+    // eslint-disable-next-line
     console.log(`> Ready on http://localhost:${port}`);
   });
 });
